'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''
'
' Product        :  First Choice Logistics Modules (tm)
'
' Name           :  log.sch
'                                                                           
' Description    :  Schema Modifications for Logistics Modules
'
' Author          : First Choice Software, Inc.
'                   4412 Spicewood Springs Road
'                   Austin, TX  78759
'                   (512) 418-2905
'
' Platforms       : This version supports Clarify 4.5 and later
'
' Copyright (C)  1997 First Choice Software, Inc.
' All Rights Reserved
'''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''''

This file describes the changes to be made to your Clarify schema for the 
First Choice Software Logistics Modules. Each of the sections describe what
you have to do, and include the sample code that must be placed in your schema
file. For example, in section 1A, it descrives the field that must be added to the
inv_bin object. Find that object in your exported schema file, and then cut the four
lines of code starting with the comma. These will be placed at the END of FIELDS section
of the INV_BIN object.

All fields and relations MUST be placed at the end of their respective sections for
their data objects.

Any relation that is declared as USER_DEFINED must be located after any other 
relations that are defined by Clarify. Both the relation and the inverse relation
must have the USER_DEFINED notation, or an error will be reported during the update.


1) NEW FIELDS TO BE ADDED TO EXISTING OBJECTS:

   A) INV_BIN:
      1) x_shippable - Long Integer
,
    x_shippable  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Do parts ship from this bin?"

   B) PART_NUM:
      1) x_shippable - Long Integer
      2) x_kit - Long Integer
      3) x_prodclass - Varchar(20)  ' Future use
      4) x_category - Varchar(20)   ' Future use

,
    x_shippable  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Is this a shippable part?"
,
    x_kit  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Is this part a kit?"
,
    x_prodclass  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Product class for the part (level 3 of family/line)"
,
    x_category  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Category for the part (level 4 of family/line)"

   C) DEMAND_HDR:
      1) x_po_num - Varchar(20)
      2) x_ship_all - Long Integer   ' Future use

,
    x_po_num  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     MANDATORY USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Purchase order number"
,
    x_ship_all  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED
     COMMENT="Must we ship all lines on this demand_hdr at one time?"

   D) DEMAND_DTL:

      1) x_order_price - float
,
    x_order_price  CMN_DATA_TYPE="float" DB_DATA_TYPE=3
     OPTIONAL USER_DEFINED
     COMMENT="Fifo cost for parts ordered. Only filled in for purchase orders."

   E) CONTR_ITM:
 
      1) details_status - Varchar(40)

,
    details_status  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=40
     COMMENT="Status of quote line item"

2) NEW RELATIONS TO BE ADDED TO EXISTING OBJECTS:

   A) CASE. Add the following to the end of the case object:
,
    case2work_order OTOP work_order USER_DEFINED
     INV_REL=work_order2case     COMMENT="What work order is this case used for?"

   B) INV_LOCATN.  Add to end of the inv_locatn object:

,
    inv_locatn2work_order OTM work_order USER_DEFINED
     INV_REL=work_order2inv_locatn     COMMENT="Work orders for this warehouse."
,
    inv_locatn2inv_sum OTM inv_sum USER_DEFINED
     INV_REL=inv_sum2inv_locatn     COMMENT="Inventory summations for this warehouse."
,
    inv_locatn2fifo_cost OTM fifo_cost USER_DEFINED
     INV_REL=fifo_cost2inv_locatn     COMMENT="Location of parts"
,
    inv_locatn2container OTM container USER_DEFINED
     INV_REL=container2inv_locatn       COMMENT="Where was the box shipped from?"
,
    inv_locatn2batch OTM batch USER_DEFINED
     INV_REL=batch2inv_locatn     COMMENT="Batches for this inventory location"

   C) MOD_LEVEL. Add to end of the mod_level object:

,
    mod_level2work_order OTM work_order USER_DEFINED
     INV_REL=work_order2mod_level     COMMENT="Work orders for this part revision."
,
    mod_level2inv_sum OTM inv_sum USER_DEFINED
     INV_REL=inv_sum2mod_level     COMMENT="Summations for this revision."
,
    mod_level2work_order_moved OTM work_order_moved USER_DEFINED
     INV_REL=moved2mod_level     COMMENT="Movements for this part."
,
    mod_level2batch_def OTM batch_def USER_DEFINED
     INV_REL=batch_def2mod_level     COMMENT="Batch defs for this part revision"

   D) DEMAND_DTL. Add to the end of the demand_dtl object:
,
    demand_dtl2batch MTO batch USER_DEFINED
     INV_REL=batch2demand_dtl     COMMENT="related part request items"
,
    demand_dtl2cont_dtl_qty OTM cont_dtl_qty USER_DEFINED
     INV_REL=cont_dtl_qty2demand_dtl       COMMENT="What item shipped in this container?"
,
    demand_dtl_p2contr_itm OTOP contr_itm USER_DEFINED
     INV_REL=contr_itm_s2demand_dtl       COMMENT="Related contract line item?"
,
    demand_dtl_s2contr_itm OTOF contr_itm USER_DEFINED
     INV_REL=contr_itm_p2demand_dtl       COMMENT="Related contract line item?"

   E) USER. Add to the end of the user object:
,
    user2batch_creator OTM batch USER_DEFINED
     INV_REL=batch_creator2user     COMMENT="Who created the batch"
,
    user2batch_closer OTM batch USER_DEFINED
     INV_REL=batch_closer2user     COMMENT="Who closed the batch"

   F) PART_NUM. Add to the end of the part_num object:
,
    part_number2fifo_cost OTM fifo_cost USER_DEFINED
     INV_REL=fifo_cost2part_number     COMMENT="Related parts"
 
   G) CONTR_ITM. Add to the end of the contr_itm object:

,
    contr_itm_s2demand_dtl OTOF demand_dtl USER_DEFINED
     INV_REL=demand_dtl_p2contr_itm       COMMENT="Related part request line item?"
,
    contr_itm_p2demand_dtl OTOP demand_dtl USER_DEFINED
     INV_REL=demand_dtl_s2contr_itm       COMMENT="Related part request line item?"

   H) CONTRACT. Add to the end of the contract object:

,
    contract_s2demand_hdr OTOF demand_hdr USER_DEFINED
     INV_REL=demand_hdr_p2contract       COMMENT="Related part request header?"
,
    contract_p2demand_hdr OTOP demand_hdr USER_DEFINED
     INV_REL=demand_hdr_s2contract       COMMENT="Related part request header?"

   I) DEMAND_HDR. Add to the end of the demand_hdr object:

,
    demand_hdr_p2contract OTOP contract USER_DEFINED
     INV_REL=contract_s2demand_hdr       COMMENT="Related contract header?"
,
    demand_hdr_s2contract OTOF contract USER_DEFINED
     INV_REL=contract_p2demand_hdr       COMMENT="Related contract header?"

   J) INV_BIN. Add to the end of the inv_bin object:

,
    inv_bin2batch_def OTM batch_def USER_DEFINED
     INV_REL=batch_def2inv_bin     COMMENT="Batch defs for this inv bin"

   K) PART_TRANS. Add to the end of the part_trans object:
   
,
    part_trans2trans_fifo_dtl OTM trans_fifo_dtl USER_DEFINED
     INV_REL=trans_fifo_dtl2part_trans     COMMENT=""

  L) SITE
,
    from_site2batch OTOF batch USER_DEFINED
     INV_REL=batch_from2site     COMMENT="From site (location) for the batch"
,
    to_site2batch OTOF batch USER_DEFINED
     INV_REL=batch_to2site     COMMENT="To site (location) for the batch"

3) NEW VIEW FIELDS TO EXISTING VIEWS:

   A) PARTS_VIEW
      1) inv_bin.x_shippable as "x_shippable"
      2) inv_bin.active as "inv_active"
      3) inv_locatn.active as "loc_active"

,   x_shippable FROM    inv_bin.x_shippable
     COMMENT="Is the bin shippable?"
,   inv_active   FROM    inv_bin.active
     COMMENT="Is the bin active?"
,   loc_active   FROM    inv_locatn.active
     COMMENT="Is the inventory location active?"

   B) PARTNUM_VIEW
      1) part_num.x_shippable as "x_shippable"
      2) mod_level.replaces_date as "replaces_date"

,   x_shippable FROM    part_num.x_shippable
     COMMENT="Is the part shippable?"
,   replaces_date FROM    mod_level.replaces_date
     COMMENT="When is the revision available?"

4) NEW OBJECTS TO BE ADDED AT THE END OF THE FILE. Cut the following code and paste
    it at the end of the schema file.

OBJECT work_order 3530
 SUBJECT="Logistics"
 COMMENT="Order to construct a finished good from raw goods"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    wo_num  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=80
     COMMENT="Work order number. Auto numbered."
,
    description  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
     COMMENT="Description of work order"
,
    qty_to_build  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="How many do we want to build. This is decremented as the units are built. When it gets to zero, the work order is closed."
,
    qty_built  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="How many have been built."
,
    status  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Status of the work order."
,
    build_all CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Must we build all of the units if there is not sufficient stock (= 1)? Or do do we want to just build as many as we have stock for? (= 0)"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    work_order2inv_locatn MTO inv_locatn USER_DEFINED
     INV_REL=inv_locatn2work_order     COMMENT="Which warehouse do we build the finished goods at?"
,
    work_order2mod_level MTO mod_level USER_DEFINED
     INV_REL=mod_level2work_order     COMMENT="Finished goods for this work order"
,
    work_order2case OTOF case USER_DEFINED
     INV_REL=case2work_order     COMMENT="What case is holding the place for the work order."
,
    work_order2work_order_moved OTM work_order_moved USER_DEFINED
     INV_REL=moved2work_order      COMMENT="Which work order is being tracked?"
  RELATIONS_END
OBJECT_END;

OBJECT work_order_moved 3531
 SUBJECT="Logistics"
 COMMENT="Tracks part revisions built against a work order."
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    qty_to_move  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="How many to move?"
,
    qty_moved  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="How many have been moved?"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    moved2work_order MTO work_order USER_DEFINED
     INV_REL=work_order2work_order_moved       COMMENT="Which work order is being tracked?"
,
    moved2mod_level MTO mod_level USER_DEFINED
     INV_REL=mod_level2work_order_moved       COMMENT="Sub-part to move"
  RELATIONS_END
OBJECT_END;

OBJECT fifo_cost 3532
 SUBJECT="FIFO Cost"
 COMMENT="To keep track of a product with different costs"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    date_avail  CMN_DATA_TYPE="clk_ty_time" DB_DATA_TYPE=9
     OPTIONAL USER_DEFINED
     COMMENT="Date parts placed in service"
,
    qty_avail  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Number of parts available"
,
    cost  CMN_DATA_TYPE="decimal" DB_DATA_TYPE=11
     OPTIONAL USER_DEFINED
     DEC_PRECISION=19
     DEC_SCALE=4
     COMMENT="Standard cost of the part number used in the FIFO record"
,
    source  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Source of the FIFO part."
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    fifo_cost2part_number MTO part_num USER_DEFINED
     INV_REL=part_number2fifo_cost     COMMENT="What part is in service"
,
    fifo_cost2inv_locatn MTO inv_locatn USER_DEFINED
     INV_REL=inv_locatn2fifo_cost     COMMENT="Where parts are stored"

  RELATIONS_END
OBJECT_END;

VIEW fifo_cost_view 3533
 SUBJECT="FIFO Cost"
 COMMENT="Information pertaining to FIFO cost"

  FIELDS
   objid        FROM    fifo_cost.objid         UNIQUE
     COMMENT="Represents inventory",
   part_number  FROM    part_num.part_number    
     COMMENT="Identifies part in inventory",
   description  FROM    part_num.description  
     COMMENT="Describes part number",
   servdate     FROM    fifo_cost.date_avail   
     COMMENT="Date received parts",
   cost FROM    fifo_cost.cost     
     COMMENT="Cost of parts",
   qty  FROM    fifo_cost.qty_avail   
     COMMENT="Number of parts received",
   location     FROM    inv_locatn.location_name    
     COMMENT="Where inventory is stored",
   source       FROM    fifo_cost.source
     COMMENT="Source of the FIFO part"
  FIELDS_END
  JOINS
    fifo_cost.fifo_cost2part_number = part_num.part_number2fifo_cost
     COMMENT="",
    fifo_cost.fifo_cost2inv_locatn = inv_locatn.inv_locatn2fifo_cost
     COMMENT=""
  JOINS_END
VIEW_END;

OBJECT batch 3534
 SUBJECT=""
 COMMENT=""
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    batch_num  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=80
     COMMENT="Batch number, autonumbered"
,
    description  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
     COMMENT="Descriptive text about the batch"
,
    status  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Status of the batch.  New code list"
,
    create_date  CMN_DATA_TYPE="clk_ty_time" DB_DATA_TYPE=9
     OPTIONAL USER_DEFINED
     COMMENT="When batch was created"
,
    close_date  CMN_DATA_TYPE="clk_ty_time" DB_DATA_TYPE=9
     OPTIONAL USER_DEFINED
     COMMENT="When batch was closed"
,
    f_retchan CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Filter - retail/channel"
,
    f_multiline  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Filter - multiline"
,
    f_nonbill  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Filter - nonbill back orders"
,
    f_overnight  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Filter - overnight"
,
    f_oneday  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Filter - oneday"
,
    f_twoday  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Filter - twoday"
,
    vendor_rma CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL PREDEFINED
     ARRAY_SIZE=80
     COMMENT="What is the vendor RMA for the batch?"
,
    skid CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL PREDEFINED
     ARRAY_SIZE=80
     COMMENT="What is the skid for the batch?"
,
    total_weight  CMN_DATA_TYPE="float" DB_DATA_TYPE=3
     OPTIONAL PREDEFINED
     COMMENT="What is the total weight of all units on the batch?"
,
    num_units  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Total number of units on the batch"
,
    waybill CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL PREDEFINED
     ARRAY_SIZE=80
     COMMENT="What is the waybill number for the batch?"
,
    shipper CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL PREDEFINED
     ARRAY_SIZE=20
     COMMENT="What is the shipper for the batch?"
,
    date_ship  CMN_DATA_TYPE="clk_ty_time" DB_DATA_TYPE=9
     OPTIONAL USER_DEFINED
     COMMENT="Date the batch was shipped"
,
    notes CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL PREDEFINED
     ARRAY_SIZE=255
     COMMENT="Extra notes for the batch?"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    batch2demand_dtl OTM demand_dtl USER_DEFINED
     INV_REL=demand_dtl2batch     COMMENT="Part request details in batch"
,
    batch_creator2user MTO user USER_DEFINED
     INV_REL=user2batch_creator     COMMENT="Who opened the batch"
,
    batch_closer2user MTO user USER_DEFINED
     INV_REL=user2batch_closer     COMMENT="Who closed the batch"
,
    batch2inv_locatn MTO inv_locatn USER_DEFINED
     INV_REL=inv_locatn2batch     COMMENT="Inventory location of batch"
,
    batch2batch_def OTM batch_def USER_DEFINED
     INV_REL=batch_def2batch     COMMENT="Batch definition items for this batch"
,
    batch_to2site OTOP site USER_DEFINED
     INV_REL=to_site2batch     COMMENT="Site of batch (to)"
,
    batch_from2site OTOP site USER_DEFINED
     INV_REL=from_site2batch     COMMENT="Site of batch (from)"
  RELATIONS_END
OBJECT_END;

OBJECT container 3535
 SUBJECT="Logistics"
 COMMENT="Tracks containers (boxes) shipped."
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    cont_num  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=80
     COMMENT="Container number, autonumbered"
,
    carrier  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Who is shipping the container?"
,
    tracking_num  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=40
     COMMENT="What is the tracking number for the container?"
,
    ship_date  CMN_DATA_TYPE="clk_ty_time" DB_DATA_TYPE=9
     OPTIONAL USER_DEFINED
     COMMENT="When was the contiainer shipped?"
,
    status  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Status of the container."
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    container2cont_dtl_qty OTM cont_dtl_qty USER_DEFINED
     INV_REL=cont_dtl_qty2container       COMMENT="How many of one item are in this box?"
,
    container2inv_locatn MTO inv_locatn USER_DEFINED
     INV_REL=inv_locatn2container       COMMENT="Where was the box shipped from?"
  RELATIONS_END
OBJECT_END;

OBJECT cont_dtl_qty 3536
 SUBJECT="Logistics"
 COMMENT="Tracks part quantities in containers(boxes) shipped."
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    qty_shipped  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="How many shipped?"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    cont_dtl_qty2demand_dtl MTO demand_dtl USER_DEFINED
     INV_REL=demand_dtl2cont_dtl_qty       COMMENT="What item shipped in this container?"
,
    cont_dtl_qty2container MTO container USER_DEFINED
     INV_REL=container2cont_dtl_qty       COMMENT="How many of one item are in this box?"
  RELATIONS_END
OBJECT_END;

VIEW container_view 3537
 SUBJECT=" "
 COMMENT=" "
  FIELDS
   objid        FROM    container.objid         UNIQUE
     COMMENT="Container object ID",
   part_number  FROM    part_num.part_number
     COMMENT="Part Number",
   mod_level    FROM    mod_level.mod_level 
     COMMENT="Revision",
   cont_num     FROM    container.cont_num  
     COMMENT="Container number",
   carrier      FROM    container.carrier   
     COMMENT="Container carrier",
   tracking_num FROM    container.tracking_num
     COMMENT="Container tracking number",
   ship_date    FROM    container.ship_date 
     COMMENT="Container ship date",
   status       FROM    container.status    
     COMMENT="Container status",
   quantity     FROM    cont_dtl_qty.qty_shipped
     COMMENT="Number of parcels in container",
   dtl_num      FROM    demand_dtl.detail_number
     COMMENT="Demand detail number",
   dtl_status   FROM    demand_dtl.details_status
     COMMENT="Demand detail status",
   location_name        FROM    inv_locatn.location_name
     COMMENT="Inventory location name"
  FIELDS_END
  JOINS
    inv_locatn.inv_locatn2container =  container.container2inv_locatn
     COMMENT="",
    container.container2cont_dtl_qty =  cont_dtl_qty.cont_dtl_qty2container
     COMMENT="",
    demand_dtl.demand_dtl2cont_dtl_qty =  cont_dtl_qty.cont_dtl_qty2demand_dtl
     COMMENT="",
    mod_level.part_info2demand_dtl =  demand_dtl.demand_dtl2part_info
     COMMENT="",
    part_num.part_num2mod_level =  mod_level.part_info2part_num
     COMMENT=""
  JOINS_END
VIEW_END;

OBJECT batch_def 3538
 SUBJECT=""
 COMMENT=""
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    type  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     DEFAULT="0"
     COMMENT="Batch def type 1=part_num filter 2=bin line item"
,
    qty  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     DEFAULT="0"
     COMMENT="Quantity in bin or part filter"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS     
    batch_def2mod_level MTO mod_level USER_DEFINED
     INV_REL=mod_level2batch_def     COMMENT="Part revisions for this batch def"
,
    batch_def2inv_bin MTO inv_bin USER_DEFINED
     INV_REL=inv_bin2batch_def    COMMENT="Inventory bins for this batch def"     
,
    batch_def2batch MTO batch USER_DEFINED
     INV_REL=batch2batch_def     COMMENT="Batch definition items for this batch"
  RELATIONS_END
OBJECT_END;

OBJECT inv_sum 3539
 SUBJECT="Logistics"
 COMMENT="Keeps track of inventory in a warehouse (summary)"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    part_number  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=30
     COMMENT="Part number available."
,
    mod_level  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=10
     COMMENT="Mod level available."
,
    location_name  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Inventory location name."
,
    on_hand  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="How many exist in the warehouse?"
,
    avail  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="How many are available for use?"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
   FIELDS_END
  RELATIONS
     inv_sum2inv_locatn MTO inv_locatn USER_DEFINED
     INV_REL=inv_locatn2inv_sum     COMMENT=""
,
    inv_sum2mod_level MTO mod_level USER_DEFINED
     INV_REL=mod_level2inv_sum    COMMENT=""
  RELATIONS_END
  INDEXES
	inv_sum_index	FIELD=part_number FIELD=mod_level FIELD=location_name  UNIQUE
  INDEXES_END
OBJECT_END;

OBJECT trans_fifo_dtl 3540
 SUBJECT="Logistics"
 COMMENT="Tracks the fifo details that were used in a part transfer"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    part_number  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=30
     COMMENT="Part number/name"
,
    date_avail  CMN_DATA_TYPE="clk_ty_time" DB_DATA_TYPE=9
     OPTIONAL USER_DEFINED
     COMMENT="Date parts placed in service"
,
    quantity  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="Number of parts used in transfer detail"
,
    source  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Source of the FIFO part."
,
    cost  CMN_DATA_TYPE="decimal" DB_DATA_TYPE=11
     OPTIONAL USER_DEFINED
     DEC_PRECISION=19
     DEC_SCALE=4
     COMMENT="Standard cost of the part number used in the transaction detail"
    FIELDS_END
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  RELATIONS
     trans_fifo_dtl2part_trans MTO part_trans USER_DEFINED
     INV_REL=part_trans2trans_fifo_dtl     COMMENT=""
  RELATIONS_END
OBJECT_END;

OBJECT fc_string 3500
 SUBJECT="System"
 COMMENT="Locale-based strings for First Choice Software Customizations"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    id  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="String ID"
,
    string  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
     COMMENT="Text  of the string"
,
    locale  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Indicates the locale of the string; e.g., EN_US=US English, JA_JP=Japanese in Japan"
,
    application  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=80
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
OBJECT_END;

OBJECT fc_list_hdr 3501
 SUBJECT="FC I18N"
 COMMENT="Header record for First Choice Software list object"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    title  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=80
     COMMENT="Name of the list"
,
    description  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
     COMMENT="Description of the list"
,
    application  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=80
     COMMENT="What is the list for?"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    hdr2fc_list_level OTOP fc_list_level USER_DEFINED
     INV_REL=level2fc_list_hdr     COMMENT="Top-level of list"

  RELATIONS_END
OBJECT_END;

OBJECT fc_list_level 3502
 SUBJECT="FC I18N"
 COMMENT="One level of a First Choice Software list"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    level2fc_list_elm OTM fc_list_elm USER_DEFINED
     INV_REL=elm2fc_list_level     COMMENT="Elements for this list level"
,
    level2fc_list_hdr OTOF fc_list_hdr USER_DEFINED
     INV_REL=hdr2fc_list_level     COMMENT="Relates top level to header"
,
    child2fc_list_elm OTOF fc_list_elm USER_DEFINED
     INV_REL=parent2fc_list_level     COMMENT="The element that this level was called from"

  RELATIONS_END
OBJECT_END;

OBJECT fc_list_elm 3503
 SUBJECT="FC I18N"
 COMMENT="One element in a First Choice Software list"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    rank  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="The position of this element in the level"
,
    state  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
     COMMENT="The state of the element. 0 = Default. 1 = Active. 2 = Inactive"
,
    fc_use  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Only used by the i18n list gui. Do not depend on this field having a value."
,
    fc_use2  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Only used by the i18n list gui. Do not depend on this field having a value."
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    elm2fc_list_level MTO fc_list_level USER_DEFINED
     INV_REL=level2fc_list_elm     COMMENT="Level for this element"
,
    parent2fc_list_level OTOP fc_list_level USER_DEFINED
     INV_REL=child2fc_list_elm     COMMENT="The sub-level for this element"
,
    locs2fc_list_locelm OTM fc_list_locelm USER_DEFINED
     INV_REL=locelm2fc_list_elm     COMMENT="The locale strings for this element"

  RELATIONS_END
OBJECT_END;

OBJECT fc_list_locelm 3504
 SUBJECT="FC I18N"
 COMMENT="One locale string for an element in a First Choice Software list"
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    title  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="String for the locale element"
,
    locale  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
     COMMENT="Locale for the locale element"
,
    other  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=80
     COMMENT="Other string for the locale element"
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
  RELATIONS
    locelm2fc_list_elm MTO fc_list_elm USER_DEFINED
     INV_REL=locs2fc_list_locelm     COMMENT="Element for this locale string"

  RELATIONS_END
OBJECT_END;

OBJECT fc_locale 3505
 SUBJECT="System"
 COMMENT=" "
  FIELDS
    objid  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY PREDEFINED
     GEN_FIELD_ID=3
     COMMENT="Internal record number"
,
    locale_name  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
,
    abday  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    day  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    abmon  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    mon  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    d_t_fmt  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    d_fmt  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    t_fmt  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    am_pm  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    t_fmt_ampm  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    upper  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    lower  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    space  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    cntrl  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    punct  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    digit  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    xdigit CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    blank  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    toupper  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    tolower  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    yesexpr  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    noexpr  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=255
,
    int_curr_symbol  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
,
    currency_symbol  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=10
,
    mon_decimal_point  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=10
,
    mon_thousands_sep  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=10
,
    mon_grouping  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED COMMENT=""
,
    positive_sign  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=10
,
    negative_sign  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=10
,
    int_frac_digits  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    frac_digits  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    p_cs_precedes  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    p_sep_by_space  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    n_cs_precedes  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    n_sep_by_space  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    p_sign_posn  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    n_sign_posn  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    decimal_point  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
,
    thousands_sep  CMN_DATA_TYPE="char pointer" DB_DATA_TYPE=7
     OPTIONAL USER_DEFINED
     ARRAY_SIZE=20
,
    grouping  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     OPTIONAL USER_DEFINED
,
    dev  CMN_DATA_TYPE="long integer" DB_DATA_TYPE=0
     MANDATORY USER_DEFINED ALLOW_NULL
     GEN_FIELD_ID=151
     DEFAULT="1"
     COMMENT="Row version number for mobile distribution purposes"
  FIELDS_END
OBJECT_END;
