/***************************************************************************/
/***  Name         : numsch.sql                                          ***/
/***                                                                     ***/
/***  Description  : Stored procedure to get the next number in a        ***/
/***                 num scheme sequence. Does it as a unit of work.     ***/
/***                                                                     ***/
/***  Author       : First Choice Software, Inc                          ***/
/***                 4412 Spicewood Springs Road Suite 701               ***/
/***                 Austin, TX 78759                                    ***/
/***                                                                     ***/
/***  Usage        : First Choice Confidential                           ***/
/***                                                                     ***/
/***  Preconditions: None known                                          ***/
/***                                                                     ***/
/***  Postcondition: None known                                          ***/
/***                                                                     ***/
/***  Platforms    : This version supports SQL Server version 6.0 or     ***/
/***                  later.                                             ***/
/***                                                                     ***/
/***                                                                     ***/
/***  Copyright (C) 1997 First Choice Software, Inc.                     ***/
/***  All Rights Reserved                                                ***/
/***                                                                     ***/
/***************************************************************************/

/***************************************************************************/
/***     Header declarations.                                            ***/
/***************************************************************************/

use <db>
go

                                        /* Drop stored procedures, if      */
                                        /*  if defined                     */
IF EXISTS (SELECT * FROM sysobjects WHERE name = 'fc_new_numsch')
   DROP PROCEDURE fc_new_numsch
go

IF EXISTS (SELECT * FROM sysobjects WHERE name = 'fc_next_pr_seq')
   DROP PROCEDURE fc_next_pr_seq
go

/***************************************************************************/
/***     Get next number in a number scheme.                             ***/
/***************************************************************************/

CREATE PROCEDURE fc_new_numsch @num_sch varchar(30), 
                              @new_num int OUTPUT AS
BEGIN
  BEGIN TRAN
  SELECT @new_num = next_value FROM table_num_scheme
    WHERE name = @num_sch
  UPDATE table_num_scheme SET next_value = next_value + 1 
    WHERE name = @num_sch
  COMMIT TRAN
END
go

/***************************************************************************/
/***     Get next number in a part request header sequence.              ***/
/***************************************************************************/

CREATE PROCEDURE fc_next_pr_seq @hdr_num varchar(20), 
                                 @new_num int OUTPUT AS
BEGIN
  BEGIN TRAN
  UPDATE table_demand_hdr SET sequence_num = sequence_num + 1 
    WHERE header_number = @hdr_num
  SELECT @new_num = sequence_num FROM table_demand_hdr
    WHERE header_number = @hdr_num
  COMMIT TRAN
END
go

/***************************************************************************/
/***     Permission granting statements.                                 ***/
/***************************************************************************/

GRANT EXECUTE ON fc_new_numsch TO PUBLIC
go

GRANT EXECUTE ON fc_next_pr_seq TO PUBLIC
go

quit
